@@ -113,12 +113,12 @@ def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date
         if date_list[0]:
             range_dict["gte"] = date_list[0]
         if len(date_list) == 2 and date_list[1]:
-            if "-" in str(date_list[1]) and is_contain_end_date:
-                end = str((datetime.strptime(date_list[1], '%Y-%m-%d') + timedelta(days=1)).strftime("%Y-%m-%d"))
-                range_dict["lt"] = end
-            else:
-                end = date_list[1]
+            end = date_list[1]
+            if is_contain_end_date:
                 range_dict["lte"] = end
+            else:
+                range_dict["lt"] = end
+
         if range_dict:
             bool_must_list.append({
                 "range": {
