@@ -21,7 +21,6 @@ from lesscode.web.router_mapping import RouterMapping
 
 define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
 define("application_path", default=f"{os.path.dirname(sys.argv[0])}", type=str, help="应用运行根路径")
-# 生成秘钥方式 print(base64.b64encode(uuid.uuid4().bytes + uuid.uuid4().bytes).decode())
 define("cookie_secret", default="hRHQlJoUQIiNai2MLV9fQV3YDpxWrUHQp/jnfF9riQk=", type=str, help="cookie 秘钥 ")
 define("static_path", default=os.path.join(f"{os.path.dirname(sys.argv[0])}", "static"), type=str, help="静态资源目录")
 define("aes_key", default="haohaoxuexi", type=str, help="aes加密key")
@@ -33,36 +32,21 @@ define("echo_sql", default=True, type=bool, help="是否启用SQL输出")
 define("async_enable", default=False, type=bool, help="是否启用异步")
 define("max_limit", default=500, type=int, help="单次查询最大数量")
 define("eureka_config", default={}, type=dict, help="eureka配置")
-define("eureka_enable", default=False, type=bool, help="是否启用eureka")
-define("eureka_server", default="", type=str, help="eureka server地址")
-define("eureka_instance_name", default="", type=str, help="eureka实例名称，大写")
-define("eureka_instance_ip", default="", type=str, help="eureka实例ip或者域名")
-define("eureka_instance_port", default=8901, type=int, help="eureka实例ip或者域名")
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
 define("running_env", default="local", type=str, help="运行环境")
 define("db", default=SQLAlchemy(), type=SQLAlchemy, help="SqlAlchemy")
 define("ks3_connect_config", default={}, type=dict, help="金山对象存储连接配置")
 define("scheduler", default=None, type=TornadoScheduler, help="Tornado任务调度")
-define("scheduler_enable", default=False, type=bool, help="Tornado任务调度")
 define("scheduler_config", default={}, type=dict, help="Tornado任务调度配置")
-define("scheduler_options", default={}, type=dict, help="Tornado任务调度选项")
 define("nacos_config", default={}, type=dict, help="nacos配置")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
 options.log_rotate_mode = "time"
 options.log_file_prefix = "log"
 options.log_rotate_when = "D"
-# options.log_rotate_interval,
 options.log_file_num_backups = 30
-options.async_enable = False
-options.eureka_enable = False
-options.eureka_server = ""
-options.eureka_instance_name = ""
-options.eureka_instance_ip = ""
-options.eureka_instance_port = None
-options.rms_register_enable = False
-options.rms_register_server = "http://127.0.0.1:8918"
+
 options.running_env = "local"
 
 
@@ -130,7 +114,7 @@ class WebServer:
         self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}",
                                  options.handler_path)
         self.autoRegisterExtendHandler()
-        if options.scheduler_enable:
+        if options.scheduler_config.get("enable", False):
             self.init_scheduler()
         self.app = tornado.web.Application(
             RouterMapping.instance(),
@@ -241,6 +225,7 @@ class WebServer:
                 __import__("{}.{}".format(pkg_name, handler_name.replace(".py", "")))
 
     def init_scheduler(self):
-        options.scheduler = TornadoScheduler(gconfig=options.scheduler_config, **options.scheduler_options)
+        options.scheduler = TornadoScheduler(gconfig=options.scheduler_config.get("config", {}),
+                                             **options.scheduler_config.get("options", {}))
         options.scheduler.start()
         logging.info('[Scheduler Init]APScheduler has been started')
